;Sample POOL code, you may use it, modify it
;and distribute it under the GPL license.
;Authors: R&D Independent Team
;Source: www.pool-rnd.com

;base class: provides functionality common
;for all derived classes of curves
to curve :c
  ;parameters of curves are stored in a
  ;dictionary of arrays:
  ;  :param,"name := {p0 min max step}
  make "param plist

  ;set new value of parameter
  to setup :name :value
    let "p :param,:name
    if :value < :p,2 ["value := :p,2]
    if :value > :p,3 ["value := :p,3]
    :param,:name,1 := :value
  end

  ;configure curve according to param. values
  to config
    foreach "p :param [make :p,1 :p,2,1]
    clean "stop := false
  end

  to fn ;prototype for the curve function:
  end   ; to be implemented in derived classes

  to draw
    config fn
    if not :stop [refresh]
  end

  ;repaint the curve on changes of display settings
  to onworldchanged
    let "nx :pool_cfg,"scale_x
    let "ny :pool_cfg,"scale_y
    let "mx :pool_cfg,"center_x
    let "my :pool_cfg,"center_y
    if (or :sx <> :nx :sy <> :ny :cx <> :mx :cy <> :my) [
      (print :nx :ny :cx :cy)
      "sx := :nx "sy := :ny
      "cx := :mx "cy := :my
      draw
    ]
  end

  ;the curve constructor stores the display settings:
  ;the scale and the position of the window center
  let "sx :pool_cfg,"scale_x
  let "sy :pool_cfg,"scale_y
  let "cx :pool_cfg,"center_x
  let "cy :pool_cfg,"center_y

  setpc :c ;set curve color
end

;setup drawing mode and shared variables
ht
window
:pool_cfg,"refresh := false

shared "stop
"stop := false

